---
title: '[릴리즈노트] 2024-07-05  업데이트'
category: 업데이트
tags:
  - 파트너정산
  - 업데이트
searchTags:
  - 과세유형
  - 파트너 과세
  - '파트너정산 기능 '
  - 권한별 기능
  - 파트너정산
  - 릴리즈노트
  - 업데이트
datetime: 2024-07-04T15:00:00.000Z
---

<Callout title="2024년 7월 5일 파트너 정산 자동화 업데이트 소식을 안내드립니다." />



<Callout content="안녕하세요. 파트너 정산 자동화팀입니다.
24년 07월 05일, 서비스 개선 사항 안내드립니다.
보안 강화 및 데이터 보호를 위한 사용자 권한별 사용 기능이 신설되었으며
정산내역관리 페이지에서 파트너 과세 유형을 확인하고 엑셀 다운로드할 수 있습니다." />

## **주요 업데이트 사항**

✔️ 권한별 기능 제한 안내



- 안전한 정산 데이터 관리를 위한 역할별 권한 관리 체계 신설
- Owner 혹은 Admin 계정에 한해 데이터 편집 권한이 부여, 그 외의 계정은 데이터 조회 권한 부여
- 사용자 별 권한 부여 및 수정은 \[상점계정관리 페이지> 관리자권한 관리 탭] 에서 Owner 혹은 Admin 계정이 직접 관리 가능
- 상세 내용은 업데이트 페이지에서 확인 가능

## 개선 사항

✔️ 파트너 업데이트 API - 과세 유형 기본값 적용

- 파트너 수정 API에서 파트너의 사업 유형 변경 시(비사업자 → 사업자)에 과세 유형이 필수값에서 선택값으로 변경
- 에러 유형이 더욱 상세하게 반환되도록 수정

✔️ 정산 내역 관리 - 엑셀 다운로드 시 파트너 과세 유형 지원



##### [\[파트너정산 릴리즈노트\] 2024-07-05 업데이트 보러가기↗](https://developers.portone.io/release-notes/platform/2024-07-05)
